| Title: | Read Binary Radar Files from 'DWD' (German Weather Service) |
|---|---|
| Description: | The 'DWD' provides gridded radar data for Germany in binary format. 'dwdradar' reads these files and enables a fast conversion into numerical format. |
| Authors: | Berry Boessenkool [aut, cre], Henning Rust [ctb], Christoph Ritschel [ctb] |
| Maintainer: | Berry Boessenkool <[email protected]> |
| License: | GPL (>= 2) |
| Version: | 0.2.13 |
| Built: | 2026-05-27 07:11:34 UTC |
| Source: | https://github.com/brry/dwdradar |
Call FORTRAN routines
bin2num(dat, len, na = NA, clutter = NA, RX = FALSE)bin2num(dat, len, na = NA, clutter = NA, RX = FALSE)
dat |
Binary data returned by |
len |
Length of data. |
na |
Value to be set for missing data (bit 14). DEFAULT: NA |
clutter |
Value to be set for clutter data (bit 16). DEFAULT: NA |
RX |
Logical: call rx routine? DEFAULT: FALSE |
numerical vector
Berry Boessenkool, [email protected], May + Oct 2019
Read and process header of binary radar files
readHeader(file)readHeader(file)
file |
Name of a single binary file |
List with original string, nchar, derived information
Berry Boessenkool, [email protected], Feb 2020
Used in readRadarFile
# See readRadarFile# See readRadarFile
Read a single binary DWD Radolan file. To be used in rdwd,
especially for proper [1/10 mm] unit correction in rdwd::readDWD.
If any files ar not read correctly, please let me know, referencing the
Kompositformatbeschreibung at https://www.dwd.de/DE/leistungen/radolan/radolan.html.
The meta-info is extracted with readHeader (not exported, but documented).
Binary bits are converted to decimal numbers with Fortran routines, see
https://github.com/brry/dwdradar/tree/master/src.
They are called via bin2num (not exported, but documented).
readRadarFile(binfile, na = NA, clutter = NA)readRadarFile(binfile, na = NA, clutter = NA)
binfile |
Name of a single binary file |
na |
Value to be set for missing data (bit 14). DEFAULT: NA |
clutter |
Value to be set for clutter data (bit 16). DEFAULT: NA |
Invisible list with dat (matrix) and meta
(list with elements from header, see Kompositformatbeschreibung).
Maintained by Berry Boessenkool, [email protected], May + Oct 2019.
Original codebase by Henning Rust & Christoph Ritschel at FU Berlin
real-world usage in rdwd: https://brry.github.io/rdwd/raster-data.html
f <- system.file("extdata/raa01_sf_2019-10-14_1950", package="dwdradar") out <- readRadarFile(f) out$meta if(requireNamespace("terra", quietly=TRUE)) terra::plot(terra::rast(out$dat)) # for more files, see the tests. # for real-world usage, readDWD.binary / readDWD.radar in the rdwd packagef <- system.file("extdata/raa01_sf_2019-10-14_1950", package="dwdradar") out <- readRadarFile(f) out$meta if(requireNamespace("terra", quietly=TRUE)) terra::plot(terra::rast(out$dat)) # for more files, see the tests. # for real-world usage, readDWD.binary / readDWD.radar in the rdwd package